get_arrow_go_version: Get the version of vendored Arrow Go using Go tooling (no...

View source: R/mangoro-bin.R

get_arrow_go_versionR Documentation

Get the version of vendored Arrow Go using Go tooling (no jsonlite)

Description

Get the version of vendored Arrow Go using Go tooling (no jsonlite)

Usage

get_arrow_go_version()

Value

The version string of github.com/apache/arrow/go/v18 in the vendor go.mod


mangoro documentation built on Nov. 26, 2025, 1:06 a.m.