get_mangos_version: Get the version of vendored mangos using Go tooling (no...

View source: R/mangoro-bin.R

get_mangos_versionR Documentation

Get the version of vendored mangos using Go tooling (no jsonlite)

Description

Get the version of vendored mangos using Go tooling (no jsonlite)

Usage

get_mangos_version()

Value

The version string of go.nanomsg.org/mangos/v3 in the vendor go.mod


mangoro documentation built on Nov. 26, 2025, 1:06 a.m.