mangoro_rpc_get_manifest: Get the manifest of registered functions from an RPC server

View source: R/mangoro-utils.R

mangoro_rpc_get_manifestR Documentation

Get the manifest of registered functions from an RPC server

Description

Get the manifest of registered functions from an RPC server

Usage

mangoro_rpc_get_manifest(sock)

Arguments

sock

A nanonext socket connected to the RPC server

Value

A list of function signatures


mangoro documentation built on Nov. 26, 2025, 1:06 a.m.