Learn R Programming

mangoro (version 0.2.6)

get_arrow_go_version: Get the version of vendored Arrow Go using Go tooling (no jsonlite)

Description

Get the version of vendored Arrow Go using Go tooling (no jsonlite)

Usage

get_arrow_go_version()

Arguments

Value

The version string of github.com/apache/arrow/go/v18 in the vendor go.mod