Learn R Programming

mangoro (version 0.2.6)

get_mangos_version: Get the version of vendored mangos using Go tooling (no jsonlite)

Description

Get the version of vendored mangos using Go tooling (no jsonlite)

Usage

get_mangos_version()

Arguments

Value

The version string of go.nanomsg.org/mangos/v3 in the vendor go.mod