mangoro_rpc_get_manifest: Get the manifest of registered functions from an RPC server
Description
Get the manifest of registered functions from an RPC server
Usage
mangoro_rpc_get_manifest(sock)
Value
A list of function signatures
Arguments
- sock
A nanonext socket connected to the RPC server